@@ -70,8 +70,7 @@ class Sequence2SequenceMixin(SequentialMixin, abc.ABC):
     compatible_head: Head = Head.SEQ2SEQ
     collator: Callable[[List[Dict[str, torch.FloatTensor]]], List[Dict[str, torch.FloatTensor]]]
 
-    def __init__(self, *args,
-                 **kwargs):
+    def __init__(self, *args, **kwargs):
         """
         Refer to the documentation of superclass.
         """
@@ -88,17 +87,22 @@ class Sequence2SequenceMixin(SequentialMixin, abc.ABC):
         # if it does not, this will just set unused attribute of tokenizer
         self.collator = DataCollatorForSeq2Seq(self.tokenizer, self.compatible_head_model, pad_to_multiple_of=8)
 
-    def _compute_loss(self, lm_logit_outputs: torch.FloatTensor, labels: torch.LongTensor) -> torch.FloatTensor:
+    def _compute_loss(self,
+                      lm_logit_outputs: torch.FloatTensor,
+                      labels: torch.LongTensor,
+                      inputs: Optional[Union[BatchEncoding, Dict[str, torch.Tensor]]] = None) -> torch.FloatTensor:
         """
         Computes sequence2sequence loss
-        :param lm_logit_outputs: Raw outputs of language modeling head model
+        :param inputs: Input encoding corresponding to given `logit_outputs` and `labels`.
+        :param logit_outputs: Raw outputs of language modeling head model
         :param labels: Token ids of expected outputs.
         :return: Single value of the loss, with grad_fn.
         """
         # note that currently we do not ignore padding from the loss, which might be desirable
         # - we have seen this to eliminate repetitive generations at some cases
         loss_fct = torch.nn.CrossEntropyLoss()
-        lm_loss = loss_fct(lm_logit_outputs.view(-1, self.tokenizer.vocab_size), labels.view(-1))
+        # vocab-agnostic loss circumvents incorrectly-set vocab_size of some models (e.g. mt5)
+        lm_loss = loss_fct(lm_logit_outputs.flatten(end_dim=1), labels.flatten())
 
         return lm_loss
 
